==> openwebbeans-2.0.9-source-release.zip: openwebbeans-2.0.9/webbeans-impl/src/test/java/org/apache/webbeans/test/component/event/normal/TransactionalInterceptor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.component.event.normal;

import javax.enterprise.inject.Intercepted;
import javax.enterprise.inject.spi.Bean;
import javax.inject.Inject;
import javax.interceptor.AroundInvoke;
import javax.interceptor.Interceptor;
import javax.interceptor.InvocationContext;
import java.io.Serializable;

import org.junit.Assert;

@Interceptor
@Transactional
public class TransactionalInterceptor implements Serializable
{

    private @Inject @Intercepted Bean<?> interceptedBean;
    private @Inject Bean<TransactionalInterceptor> bean;
    private @Inject javax.enterprise.inject.spi.Interceptor <TransactionalInterceptor> interceptor;


    @AroundInvoke
    public Object caller(InvocationContext context) throws Exception
    {
        checkInjections();
        try
        {
            ComponentWithObserves2.hasBeenIntercepted = true;
            return context.proceed();
            
        }catch(Exception e)
        {
            ComponentWithObserves2.hasBeenIntercepted = false;
        }
        
        return null;
    }

    private void checkInjections()
    {
        Assert.assertNotNull(interceptedBean);
        Assert.assertNotNull(bean);
        Assert.assertNotNull(interceptor);
    }

}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/component/event/normal/TransactionalInterceptor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.component.event.normal;

import jakarta.enterprise.inject.Intercepted;
import jakarta.enterprise.inject.spi.Bean;
import jakarta.inject.Inject;
import jakarta.interceptor.AroundInvoke;
import jakarta.interceptor.Interceptor;
import jakarta.interceptor.InvocationContext;
import java.io.Serializable;

import org.junit.Assert;

@Interceptor
@Transactional
public class TransactionalInterceptor implements Serializable
{

    private @Inject @Intercepted Bean<?> interceptedBean;
    private @Inject Bean<TransactionalInterceptor> bean;
    private @Inject jakarta.enterprise.inject.spi.Interceptor <TransactionalInterceptor> interceptor;


    @AroundInvoke
    public Object caller(InvocationContext context) throws Exception
    {
        checkInjections();
        try
        {
            ComponentWithObserves2.hasBeenIntercepted = true;
            return context.proceed();
            
        }catch(Exception e)
        {
            ComponentWithObserves2.hasBeenIntercepted = false;
        }
        
        return null;
    }

    private void checkInjections()
    {
        Assert.assertNotNull(interceptedBean);
        Assert.assertNotNull(bean);
        Assert.assertNotNull(interceptor);
    }

}
